@@ -15,7 +15,7 @@ from darwin.exceptions import (
     NotFound,
     Unauthorized,
 )
-from darwin.utils import is_project_dir, urljoin
+from darwin.utils import is_project_dir, urljoin, is_deprecated_project_dir
 from darwin.validators import name_taken, validation_error
 
 
@@ -28,12 +28,7 @@ class Client:
         self.features = {}
 
     def get(
-        self,
-        endpoint: str,
-        team: Optional[str] = None,
-        retry: bool = False,
-        raw: bool = False,
-        debug: bool = False,
+        self, endpoint: str, team: Optional[str] = None, retry: bool = False, raw: bool = False, debug: bool = False
     ):
         """Get something from the server trough HTTP
 
@@ -82,12 +77,7 @@ class Client:
             return self._decode_response(response, debug)
 
     def put(
-        self,
-        endpoint: str,
-        payload: Dict,
-        team: Optional[str] = None,
-        retry: bool = False,
-        debug: bool = False,
+        self, endpoint: str, payload: Dict, team: Optional[str] = None, retry: bool = False, debug: bool = False
     ):
         """Put something on the server trough HTTP
 
@@ -107,9 +97,7 @@ class Client:
         dict
         Dictionary which contains the server response
         """
-        response = requests.put(
-            urljoin(self.url, endpoint), json=payload, headers=self._get_headers(team)
-        )
+        response = requests.put(urljoin(self.url, endpoint), json=payload, headers=self._get_headers(team))
 
         if response.status_code == 401:
             raise Unauthorized()
@@ -165,9 +153,7 @@ class Client:
             payload = {}
         if error_handlers is None:
             error_handlers = []
-        response = requests.post(
-            urljoin(self.url, endpoint), json=payload, headers=self._get_headers(team)
-        )
+        response = requests.post(urljoin(self.url, endpoint), json=payload, headers=self._get_headers(team))
         if response.status_code == 401:
             raise Unauthorized()
 
@@ -189,17 +175,37 @@ class Client:
         return self._decode_response(response, debug)
 
     def list_local_datasets(self, team: Optional[str] = None) -> Iterator[Path]:
-        """Returns a list of all local folders who are detected as dataset.
+        """Returns a list of all local folders which are detected as dataset.
 
         Returns
         -------
         list[Path]
         List of all local datasets
         """
-        team_config = self.config.get_team(team or self.default_team)
+        if team is not None:
+            team_configs = [self.config.get_team(team)]
+        else:
+            team_configs = self.config.get_all_teams()
+        for team_config in team_configs:
+            projects_team = Path(team_config["datasets_dir"]) / team_config["slug"]
+            for project_path in projects_team.glob("*"):
+                if project_path.is_dir() and is_project_dir(project_path):
+                    yield Path(project_path)
 
-        for project_path in Path(team_config["datasets_dir"]).glob("*"):
-            if project_path.is_dir() and is_project_dir(project_path):
+    def list_deprecated_local_datasets(self, team: Optional[str] = None) -> Iterator[Path]:
+        """Returns a list of all local folders which are detected as datasets but use a deprecated local structure
+
+        Returns
+        -------
+        list[Path]
+        List of all local datasets
+        """
+        team = team or self.default_team
+        team_config = self.config.get_team(team)
+
+        projects_team = Path(team_config["datasets_dir"])
+        for project_path in projects_team.glob("*"):
+            if project_path.is_dir() and is_deprecated_project_dir(project_path):
                 yield Path(project_path)
 
     def list_remote_datasets(self, team: Optional[str] = None) -> Iterator[RemoteDataset]:
@@ -221,9 +227,7 @@ class Client:
                 client=self,
             )
 
-    def get_remote_dataset(
-        self, dataset_identifier: Union[str, DatasetIdentifier]
-    ) -> RemoteDataset:
+    def get_remote_dataset(self, dataset_identifier: Union[str, DatasetIdentifier]) -> RemoteDataset:
         """Get a remote dataset based on the parameter passed. You can only choose one of the
         possible parameters and calling this method with multiple ones will result in an
         error.
@@ -242,7 +246,6 @@ class Client:
             dataset_identifier = DatasetIdentifier.parse(dataset_identifier)
         if not dataset_identifier.team_slug:
             dataset_identifier.team_slug = self.default_team
-
         matching_datasets = [
             dataset
             for dataset in self.list_remote_datasets(team=dataset_identifier.team_slug)
@@ -265,9 +268,7 @@ class Client:
         RemoteDataset
         The created dataset
         """
-        dataset = self.post(
-            "/datasets", {"name": name}, team=team, error_handlers=[name_taken, validation_error]
-        )
+        dataset = self.post("/datasets", {"name": name}, team=team, error_handlers=[name_taken, validation_error])
         return RemoteDataset(
             name=dataset["name"],
             team=team or self.default_team,
