@@ -21,41 +21,30 @@ class Options(object):
         parser_create = subparsers.add_parser("team", help="List or pick teams. ")
         parser_create.add_argument("team_name", nargs="?", type=str, help="Team name to use. ")
         parser_create.add_argument(
-            "-c",
-            "--current",
-            action="store_true",
-            required=False,
-            help="Shows only the current team. ",
+            "-c", "--current", action="store_true", required=False, help="Shows only the current team. ",
         )
 
-        parser_convert = subparsers.add_parser(
-            "convert", help="Converts darwin json to other annotation formats."
-        )
+        parser_convert = subparsers.add_parser("convert", help="Converts darwin json to other annotation formats.")
         parser_convert.add_argument("format", type=str, help="Annotation import to convert to")
 
-        parser_convert.add_argument(
-            "files", type=str, nargs="+", help="Annotation files (or folders) to convert"
-        )
+        parser_convert.add_argument("files", type=str, nargs="+", help="Annotation files (or folders) to convert")
 
         parser_convert.add_argument("output_dir", type=str, help="Where to store output files")
 
         # DATASET
         dataset = subparsers.add_parser(
-            "dataset",
-            help="Dataset related functions",
-            description="Arguments to interact with datasets",
+            "dataset", help="Dataset related functions", description="Arguments to interact with datasets",
         )
         dataset_action = dataset.add_subparsers(dest="action")
 
         # Remote
         parser_remote = dataset_action.add_parser("remote", help="List remote datasets")
         parser_remote.add_argument("-t", "--team", help="Specify team")
-        parser_remote.add_argument(
-            "-a", "--all", action="store_true", help="List datasets for all teams"
-        )
+        parser_remote.add_argument("-a", "--all", action="store_true", help="List datasets for all teams")
 
         # Local
-        dataset_action.add_parser("local", help="List downloaded datasets")
+        parser_local = dataset_action.add_parser("local", help="List downloaded datasets")
+        parser_local.add_argument("-t", "--team", help="Specify team")
 
         # Create
         parser_create = dataset_action.add_parser("create", help="Creates a new dataset on darwin")
@@ -71,9 +60,7 @@ class Options(object):
         parser_url.add_argument("dataset", type=str, help="Dataset name")
 
         # Push
-        parser_push = dataset_action.add_parser(
-            "push", help="Upload data to an existing (remote) dataset."
-        )
+        parser_push = dataset_action.add_parser("push", help="Upload data to an existing (remote) dataset.")
         parser_push.add_argument(
             "dataset",
             type=str,
@@ -89,55 +76,36 @@ class Options(object):
             help="Excludes the files with the specified extension/s if a data folder is provided as data path. ",
         )
         parser_push.add_argument(
-            "-f",
-            "--fps",
-            type=int,
-            default="1",
-            help="Frames per second for video split (recommended: 1).",
+            "-f", "--fps", type=int, default="1", help="Frames per second for video split (recommended: 1).",
         )
 
         # Remove
-        parser_remove = dataset_action.add_parser(
-            "remove", help="Remove a remote or remote and local dataset."
-        )
+        parser_remove = dataset_action.add_parser("remove", help="Remove a remote or remote and local dataset.")
         parser_remove.add_argument("dataset", type=str, help="Remote dataset name to delete.")
 
         # Report
         parser_report = dataset_action.add_parser("report", help="Report about the annotators ")
         parser_report.add_argument("dataset", type=str, help="Remote dataset name to report on.")
         parser_report.add_argument(
-            "-g",
-            "--granularity",
-            choices=["day", "week", "month", "total"],
-            help="Granularity of the report",
+            "-g", "--granularity", choices=["day", "week", "month", "total"], help="Granularity of the report",
         )
 
         # Export
-        parser_export = dataset_action.add_parser(
-            "export", help="Export the a version of a dataset."
-        )
+        parser_export = dataset_action.add_parser("export", help="Export a version of a dataset.")
         parser_export.add_argument("dataset", type=str, help="Remote dataset name to export.")
         parser_export.add_argument("name", type=str, help="Name with with the version gets tagged.")
-        parser_export.add_argument(
-            "annotation_class", type=str, nargs="?", help="List of class filters"
-        )
+        parser_export.add_argument("annotation_class", type=str, nargs="?", help="List of class filters")
 
         # Releases
-        parser_dataset_version = dataset_action.add_parser(
-            "releases", help="Available version of a dataset."
-        )
-        parser_dataset_version.add_argument(
-            "dataset", type=str, help="Remote dataset name to list."
-        )
+        parser_dataset_version = dataset_action.add_parser("releases", help="Available version of a dataset.")
+        parser_dataset_version.add_argument("dataset", type=str, help="Remote dataset name to list.")
 
         # Pull
         parser_pull = dataset_action.add_parser("pull", help="Download a version of a dataset.")
         parser_pull.add_argument("dataset", type=str, help="Remote dataset name to download.")
 
         # Import
-        parser_import = dataset_action.add_parser(
-            "import", help="Import data to an existing (remote) dataset."
-        )
+        parser_import = dataset_action.add_parser("import", help="Import data to an existing (remote) dataset.")
         parser_import.add_argument(
             "dataset",
             type=str,
@@ -145,14 +113,10 @@ class Options(object):
         )
         parser_import.add_argument("format", type=str, help="Annotation import to import")
 
-        parser_import.add_argument(
-            "files", type=str, nargs="+", help="Annotation files (or folders) to import"
-        )
+        parser_import.add_argument("files", type=str, nargs="+", help="Annotation files (or folders) to import")
 
         # Convet
-        parser_convert = dataset_action.add_parser(
-            "convert", help="Converts darwin json to other annotation formats."
-        )
+        parser_convert = dataset_action.add_parser("convert", help="Converts darwin json to other annotation formats.")
         parser_convert.add_argument(
             "dataset",
             type=str,
@@ -162,6 +126,21 @@ class Options(object):
 
         parser_convert.add_argument("output_dir", type=str, help="Where to store output files")
 
+        # Migrate
+        parser_migrate = dataset_action.add_parser("migrate", help="Migrate a local dataset to the latest version.")
+        parser_migrate.add_argument("dataset", type=str, help="Local dataset name to migrate.")
+
+        # Split
+        parser_split = dataset_action.add_parser(
+            "split", help="Splits a local dataset following random and stratified split types."
+        )
+        parser_split.add_argument("dataset", type=str, help="Local dataset name to split.")
+        parser_split.add_argument("-v", "--val-percentage", type=float, required=True, help="Validation percentage.")
+        parser_split.add_argument(
+            "-t", "--test-percentage", type=float, required=False, default=0, help="Test percentage.",
+        )
+        parser_split.add_argument("-s", "--seed", type=int, required=False, default=0, help="Split seed.")
+
         # Help
         dataset_action.add_parser("help", help="Show this help message and exit.")
 
