@@ -1,147 +1,66 @@
-import json
 import multiprocessing as mp
 from pathlib import Path
-from typing import Callable, Collection, List, Optional
+from typing import Collection, List, Optional, Union
 
 import numpy as np
 
-import torch.utils.data as data
-from darwin.torch.transforms import Compose, ConvertPolygonsToInstanceMasks, ConvertPolygonToMask
+from darwin.dataset import LocalDataset
+from darwin.torch.transforms import Compose, ConvertPolygonsToInstanceMasks, ConvertPolygonsToSegmentationMask
 from darwin.torch.utils import convert_polygons_to_sequences, load_pil_image, polygon_area
-from darwin.utils import SUPPORTED_IMAGE_EXTENSIONS, is_image_extension_allowed
 
 
-class Dataset(data.Dataset):
-    def __init__(self, root: Path, split: Path, transform: Optional[List] = None):
-        """ Creates a dataset
+def get_dataset(
+    dataset_path: Union[Path, str],
+    dataset_type: str,
+    partition: Optional[str] = None,
+    split: str = "default",
+    split_type: str = "random",
+    release_name: Optional[str] = None,
+    transform: Optional[List] = None,
+):
+    """ Creates and returns a dataset
 
-        Parameters
-        ----------
-        root : Path
-            Path to the location of the dataset on the file system
-        split : Path
-            Path to the *.txt file containing the list of files for this split.
-        transform : list[torchvision.transforms]
-            List of PyTorch transforms
-        """
-        self.root = root
-        self.split = split
-        self.transform = transform
-        self.images_path: List[Path] = []
-        self.annotations_path: List[Path] = []
-        self.classes = None
-        self.original_classes = None
-        self.original_images_path: Optional[List[Path]] = None
-        self.original_annotations_path: Optional[List[Path]] = None
-        self.convert_polygons: Optional[Callable] = None
+    Parameters
+    ----------
+    dataset_path: Path, str
+        Path to the location of the dataset on the file system
+    dataset_type: str
+        The type of dataset [classification, instance_segmentation, semantic_segmentation]
+    partition: str
+        Selects one of the partitions [train, val, test]
+    split: str
+        Selects the split that defines the percentages used (use 'default' to select the default split)
+    split_type: str
+        Heuristic used to do the split [random, stratified]
+    release_name: str
+        Version of the dataset
+    transform : list[torchvision.transforms]
+        List of PyTorch transforms
+    """
+    dataset_functions = {
+        "classification": ClassificationDataset,
+        "instance_segmentation": InstanceSegmentationDataset,
+        "semantic_segmentation": SemanticSegmentationDataset,
+    }
+    dataset_function = dataset_functions.get(dataset_type)
+    if not dataset_function:
+        list_of_types = ", ".join(dataset_functions.keys())
+        raise ValueError(f"dataset_type needs to be one of '{list_of_types}'")
 
-        # Compose the transform if necessary
-        if self.transform is not None and isinstance(self.transform, list):
-            self.transform = Compose(transform)
+    if isinstance(dataset_path, str):
+        dataset_path = Path(dataset_path)
 
-        # Populate internal lists of annotations and images paths
-        if not self.split.exists():
-            raise FileNotFoundError(f"Could not find partition file: {self.split}")
-        stems = (e.strip() for e in split.open())
-        image_extensions_mapping = {
-            image.stem: image.suffix
-            for image in self.root.glob(f"images/*")
-            if is_image_extension_allowed(image.suffix)
-        }
-        for stem in stems:
-            annotation_path = self.root / f"annotations/{stem}.json"
-            try:
-                extension = image_extensions_mapping[stem]
-            except KeyError:
-                raise ValueError(
-                    f"Annotation ({annotation_path}) does not have a corresponding image"
-                )
-            image_path = self.root / f"images/{stem}{extension}"
-            self.images_path.append(image_path)
-            self.annotations_path.append(annotation_path)
+    return dataset_function(
+        dataset_path=dataset_path,
+        partition=partition,
+        split=split,
+        split_type=split_type,
+        release_name=release_name,
+        transform=transform,
+    )
 
-        if len(self.images_path) == 0:
-            raise ValueError(
-                f"Could not find any {SUPPORTED_IMAGE_EXTENSIONS} file"
-                f" in {self.root / 'images'}"
-            )
-
-        assert len(self.images_path) == len(self.annotations_path)
-
-    def extend(self, dataset, extend_classes: bool = False):
-        """Extends the current dataset with another one
-
-        Parameters
-        ----------
-        dataset : Dataset
-            Dataset to merge
-        extend_classes : bool
-            Extend the current set of classes by merging with the passed dataset ones
-
-        Returns
-        -------
-        Dataset
-            self
-        """
-        if self.classes != dataset.classes and not extend_classes:
-            raise ValueError(
-                f"Operation dataset_a + dataset_b could not be computed: classes "
-                f"should match. Use flag extend_classes=True to combine both lists "
-                f"of classes."
-            )
-        self.classes = list(set(self.classes).union(set(dataset.classes)))
-
-        self.original_images_path = self.images_path
-        self.images_path += dataset.images_path
-        self.original_annotations_path = self.annotations_path
-        self.annotations_path += dataset.annotations_path
-        return self
-
-    def get_img_info(self, index: int):
-        with self.annotations_path[index].open() as f:
-            data = json.load(f)["image"]
-            return data
-
-    def get_height_and_width(self, index: int):
-        data = self.get_img_info(index)
-        return data["height"], data["width"]
-
-    def _map_annotation(self, index: int):
-        """
-        Load an annotation and filter out the extra classes according to what
-        specified in `self.classes`
-
-        Parameters
-        ----------
-        index : int
-            Index of the annotation to read
-
-        Returns
-        -------
-        dict
-        A new dictionary containing the index and the filtered annotation
-
-        Notes
-        -----
-        The return value is a dict with the following fields:
-            image_id: int
-                The index of the image in the split
-            original_filename: str
-                The path to the image on the file system
-            annotations : str
-                The original raw annotation
-        """
-        with self.annotations_path[index].open() as f:
-            annotation = json.load(f)["annotations"]
-        # Filter out unused classes
-        if self.classes is not None:
-            annotation = [a for a in annotation if a["name"] in self.classes]
-        return {
-            "image_id": index,
-            "original_filename": self.images_path[index],
-            "annotations": annotation,
-        }
 
+class DarwinDataset(LocalDataset):
     def measure_mean_std(self, multi_threaded: bool = True):
         """Computes mean and std of train images, given the train loader
 
@@ -164,9 +83,7 @@ class Dataset(data.Dataset):
                 results = pool.map(self._return_mean, self.images_path)
                 mean = np.sum(np.array(results), axis=0) / len(self.images_path)
                 # Online image_classification deviation
-                results = pool.starmap(
-                    self._return_std, [[item, mean] for item in self.images_path]
-                )
+                results = pool.starmap(self._return_std, [[item, mean] for item in self.images_path])
                 std_sum = np.sum(np.array([item[0] for item in results]), axis=0)
                 total_pixel_count = np.sum(np.array([item[1] for item in results]))
                 std = np.sqrt(std_sum / total_pixel_count)
@@ -228,68 +145,22 @@ class Dataset(data.Dataset):
     @staticmethod
     def _return_std(image_path, mean):
         img = np.array(load_pil_image(image_path)) / 255.0
-        m2 = np.square(
-            np.array([img[:, :, 0] - mean[0], img[:, :, 1] - mean[1], img[:, :, 2] - mean[2]])
-        )
+        m2 = np.square(np.array([img[:, :, 0] - mean[0], img[:, :, 1] - mean[1], img[:, :, 2] - mean[2]]))
         return np.sum(np.sum(m2, axis=1), 1), m2.size / 3.0
 
-    def __add__(self, dataset):
-        """Adds the passed dataset to the current one
 
-        Parameters
-        ----------
-        dataset : Dataset
-            Dataset to merge
+class ClassificationDataset(DarwinDataset):
+    def __init__(
+        self, transform: Optional[List] = None, **kwargs,
+    ):
+        """See class `LocalDataset` for documentation"""
+        super().__init__(annotation_type="tag", **kwargs)
 
-        Returns
-        -------
-        Dataset
-            self
-        """
-        if self.classes != dataset.classes:
-            raise ValueError(
-                f"Operation dataset_a + dataset_b could not be computed: classes should match."
-                f"Use dataset_a.extend(dataset_b, extend_classes=True) to combine both lists of classes"
-            )
-        self.original_images_path = self.images_path
-        self.images_path += dataset.images_path
-        self.original_annotations_path = self.annotations_path
-        self.annotations_path += dataset.annotations_path
-        return self
+        self.transform = transform
+        if self.transform is not None and isinstance(self.transform, list):
+            self.transform = Compose(self.transform)
 
     def __getitem__(self, index: int):
-        # Load images and masks
-        img = load_pil_image(self.images_path[index])
-        target = self._map_annotation(index)
-        if self.convert_polygons is not None:
-            img, target = self.convert_polygons(img, target)
-        if self.transform is not None:
-            img, target = self.transform(img, target)
-        return img, target
-
-    def __len__(self):
-        return len(self.images_path)
-
-    def __str__(self):
-        return (
-            f"{self.__class__.__name__}():\n"
-            f"  Root: {self.root}\n"
-            f"  Number of images: {len(self.images_path)}"
-        )
-
-
-####################################################################################################
-
-
-class ClassificationDataset(Dataset):
-    def __init__(self, root: Path, split: Path, transform: Optional[List] = None):
-        """See superclass for documentation"""
-        super().__init__(root=root, split=split, transform=transform)
-        self.classes = [
-            e.strip() for e in (self.root / "lists/classes_tag.txt").read_text().split("\n")
-        ]
-
-    def _map_annotation(self, index: int):
         """See superclass for documentation
 
         Notes
@@ -302,24 +173,25 @@ class ClassificationDataset(Dataset):
             category_id : int
                 The single label of the image selected.
         """
-        with self.annotations_path[index].open() as f:
-            annotation = json.load(f)["annotations"]
-            tags = [self.classes.index(a["name"]) for a in annotation if "tag" in a]
-            if len(tags) > 1:
-                raise ValueError(
-                    f"Multiple tags defined for this image ({tags}). "
-                    f"This is not valid in a classification dataset."
-                )
-            if len(tags) == 0:
-                raise ValueError(
-                    f"No tags defined for this image ({self.annotations_path[index]})."
-                    f"This is not valid in a classification dataset."
-                )
-        return {
-            "image_id": index,
-            "original_filename": self.images_path[index],
-            "category_id": tags[0],
-        }
+        img = load_pil_image(self.images_path[index])
+        if self.transform is not None:
+            img = self.transform(img)
+
+        target = self.parse_json(index)
+        annotations = target.pop("annotations")
+        tags = [self.classes.index(a["name"]) for a in annotations if "tag" in a]
+        if len(tags) > 1:
+            raise ValueError(
+                f"Multiple tags defined for this image ({tags}). " f"This is not valid in a classification dataset."
+            )
+        if len(tags) == 0:
+            raise ValueError(
+                f"No tags defined for this image ({self.annotations_path[index]})."
+                f"This is not valid in a classification dataset."
+            )
+        target["category_id"] = tags[0]
+
+        return img, target
 
     def measure_weights(self, **kwargs) -> np.ndarray:
         """Computes the class balancing weights (not the frequencies!!) given the train loader
@@ -339,28 +211,21 @@ class ClassificationDataset(Dataset):
         return self._compute_weights(labels)
 
 
-####################################################################################################
-
-
-class InstanceSegmentationDataset(Dataset):
+class InstanceSegmentationDataset(DarwinDataset):
     def __init__(
-        self,
-        root: Path,
-        split: Path,
-        transform: Optional[List] = None,
-        convert_polygons_to_masks: Optional[bool] = True,
+        self, transform: Optional[List] = None, convert_polygons_to_masks: Optional[bool] = True, **kwargs,
     ):
-        """See superclass for documentation"""
-        super().__init__(root=root, split=split, transform=transform)
-        self.classes = [
-            e.strip() for e in (self.root / "lists/classes_polygon.txt").read_text().split("\n")
-        ]
-        self.convert_polygons = (
-            ConvertPolygonsToInstanceMasks() if convert_polygons_to_masks else None
-        )
+        """See `LocalDataset` class for documentation"""
+        super().__init__(annotation_type="polygon", **kwargs)
 
-    def _map_annotation(self, index: int):
-        """See superclass for documentation
+        self.transform = transform
+        if self.transform is not None and isinstance(self.transform, list):
+            self.transform = Compose(self.transform)
+
+        self.convert_polygons = ConvertPolygonsToInstanceMasks() if convert_polygons_to_masks else None
+
+    def __getitem__(self, index: int):
+        """
 
         Notes
         -----
@@ -380,15 +245,11 @@ class InstanceSegmentationDataset(Dataset):
                 area : float
                     Area of the polygon
         """
-        with self.annotations_path[index].open() as f:
-            annotations = json.load(f)["annotations"]
+        img = load_pil_image(self.images_path[index])
+        target = self.parse_json(index)
 
-        # Filter out unused classes
-        if self.classes is not None:
-            annotations = [a for a in annotations if a["name"] in self.classes]
-
-        target = []
-        for annotation in annotations:
+        annotations = []
+        for annotation in target["annotations"]:
             assert "name" in annotation
             assert "polygon" in annotation
             # Extract the sequences of coordinates from the polygon annotation
@@ -408,13 +269,11 @@ class InstanceSegmentationDataset(Dataset):
             h = max_y - min_y + 1
             bbox_area = w * h
             # Compute the area of the polygon
-            poly_area = np.sum(
-                [polygon_area(x_coord, y_coord) for x_coord, y_coord in zip(x_coords, y_coords)]
-            )
+            poly_area = np.sum([polygon_area(x_coord, y_coord) for x_coord, y_coord in zip(x_coords, y_coords)])
             assert poly_area <= bbox_area
 
             # Create and append the new entry for this annotation
-            target.append(
+            annotations.append(
                 {
                     "category_id": self.classes.index(annotation["name"]),
                     "segmentation": sequences,
@@ -422,12 +281,14 @@ class InstanceSegmentationDataset(Dataset):
                     "area": poly_area,
                 }
             )
+        target["annotations"] = annotations
 
-        return {
-            "image_id": index,
-            "original_filename": self.images_path[index],
-            "annotations": target,
-        }
+        if self.convert_polygons is not None:
+            img, target = self.convert_polygons(img, target)
+        if self.transform is not None:
+            img, target = self.transform(img, target)
+
+        return img, target
 
     def measure_weights(self, **kwargs):
         """Computes the class balancing weights (not the frequencies!!) given the train loader
@@ -447,27 +308,20 @@ class InstanceSegmentationDataset(Dataset):
         return self._compute_weights(labels)
 
 
-####################################################################################################
-
-
-class SemanticSegmentationDataset(Dataset):
+class SemanticSegmentationDataset(DarwinDataset):
     def __init__(
-        self,
-        root: Path,
-        split: Path,
-        transform: Optional[List] = None,
-        convert_polygons_to_masks: Optional[bool] = True,
+        self, transform: Optional[List] = None, convert_polygons_to_masks: Optional[bool] = True, **kwargs,
     ):
-        """See superclass for documentation"""
-        super().__init__(root=root, split=split, transform=transform)
-        self.classes = [
-            e.strip() for e in (self.root / "lists/classes_polygon.txt").read_text().split("\n")
-        ]
-        if self.classes[0] == "__background__":
-            self.classes = self.classes[1:]
-        self.convert_polygons = ConvertPolygonToMask() if convert_polygons_to_masks else None
+        """See `LocalDataset` class for documentation"""
+        super().__init__(annotation_type="polygon", **kwargs)
 
-    def _map_annotation(self, index: int):
+        self.transform = transform
+        if self.transform is not None and isinstance(self.transform, list):
+            self.transform = Compose(self.transform)
+
+        self.convert_polygons = ConvertPolygonsToSegmentationMask() if convert_polygons_to_masks else None
+
+    def __getitem__(self, index: int):
         """See superclass for documentation
 
         Notes
@@ -482,31 +336,27 @@ class SemanticSegmentationDataset(Dataset):
                 category_id : TODO complete documentation
                 segmentation :
         """
-        with self.annotations_path[index].open() as f:
-            annotation = json.load(f)["annotations"]
+        img = load_pil_image(self.images_path[index])
+        target = self.parse_json(index)
 
-        # Filter out unused classes
-        if self.classes is not None:
-            annotation = [obj for obj in annotation if obj["name"] in self.classes]
-
-        target = []
-        for obj in annotation:
+        annotations = []
+        for obj in target["annotations"]:
             sequences = convert_polygons_to_sequences(obj["polygon"]["path"])
             # Discard polygons with less than three points
             sequences[:] = [s for s in sequences if len(s) >= 6]
             if not sequences:
                 continue
-            target.append(
-                {
-                    "category_id": self.classes.index(obj["name"]),
-                    "segmentation": np.array(sequences),
-                }
+            annotations.append(
+                {"category_id": self.classes.index(obj["name"]), "segmentation": np.array(sequences),}
             )
-        return {
-            "image_id": index,
-            "original_filename": self.images_path[index],
-            "annotations": target,
-        }
+        target["annotations"] = annotations
+
+        if self.convert_polygons is not None:
+            img, target = self.convert_polygons(img, target)
+        if self.transform is not None:
+            img, target = self.transform(img, target)
+
+        return img, target
 
     def measure_weights(self, **kwargs):
         """Computes the class balancing weights (not the frequencies!!) given the train loader
